DescribeAgentResponse class

DescribeAgentResponse

Constructors

DescribeAgentResponse({String? agentArn, DateTime? creationTime, EndpointType? endpointType, DateTime? lastConnectionTime, String? name, PrivateLinkConfig? privateLinkConfig, AgentStatus? status})
DescribeAgentResponse.fromJson(Map<String, dynamic> json)
factory

Properties

agentArn → String?
The Amazon Resource Name (ARN) of the agent.
final
creationTime → DateTime?
The time that the agent was activated (that is, created in your account).
final
endpointType → EndpointType?
The type of endpoint that your agent is connected to. If the endpoint is a VPC endpoint, the agent is not accessible over the public internet.
final
hashCode → int
The hash code for this object.
no setterinherited
lastConnectionTime → DateTime?
The time that the agent last connected to DataSyc.
final
name → String?
The name of the agent.
final
privateLinkConfig → PrivateLinkConfig?
The subnet and the security group that DataSync used to access a VPC endpoint.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → AgentStatus?
The status of the agent. If the status is ONLINE, then the agent is configured properly and is available to use. The Running status is the normal running status for an agent. If the status is OFFLINE, the agent's VM is turned off or the agent is in an unhealthy state. When the issue that caused the unhealthy state is resolved, the agent returns to ONLINE status.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited