DescribeLocationObjectStorageResponse class

DescribeLocationObjectStorageResponse

Constructors

DescribeLocationObjectStorageResponse({String? accessKey, List<String>? agentArns, DateTime? creationTime, String? locationArn, String? locationUri, int? serverPort, ObjectStorageServerProtocol? serverProtocol})
DescribeLocationObjectStorageResponse.fromJson(Map<String, dynamic> json)
factory

Properties

accessKey → String?
Optional. The access key is used if credentials are required to access the self-managed object storage server. If your object storage requires a user name and password to authenticate, use AccessKey and SecretKey to provide the user name and password, respectively.
final
agentArns → List<String>?
The Amazon Resource Name (ARN) of the agents associated with the self-managed object storage server location.
final
creationTime → DateTime?
The time that the self-managed object storage server agent was created.
final
hashCode → int
The hash code for this object.
no setterinherited
locationArn → String?
The Amazon Resource Name (ARN) of the self-managed object storage server location to describe.
final
locationUri → String?
The URL of the source self-managed object storage server location that was described.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverPort → int?
The port that your self-managed object storage server accepts inbound network traffic on. The server port is set by default to TCP 80 (HTTP) or TCP 443 (HTTPS).
final
serverProtocol → ObjectStorageServerProtocol?
The protocol that the object storage server uses to communicate. Valid values are HTTP or HTTPS.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited