DescribeTaskExecutionResponse class

DescribeTaskExecutionResponse

Constructors

DescribeTaskExecutionResponse({int? bytesTransferred, int? bytesWritten, int? estimatedBytesToTransfer, int? estimatedFilesToTransfer, List<FilterRule>? excludes, int? filesTransferred, List<FilterRule>? includes, Options? options, TaskExecutionResultDetail? result, DateTime? startTime, TaskExecutionStatus? status, String? taskExecutionArn})
DescribeTaskExecutionResponse.fromJson(Map<String, dynamic> json)
factory

Properties

bytesTransferred → int?
The physical number of bytes transferred over the network.
final
bytesWritten → int?
The number of logical bytes written to the destination AWS storage resource.
final
estimatedBytesToTransfer → int?
The estimated physical number of bytes that is to be transferred over the network.
final
estimatedFilesToTransfer → int?
The expected number of files that is to be transferred over the network. This value is calculated during the PREPARING phase, before the TRANSFERRING phase. This value is the expected number of files to be transferred. It's calculated based on comparing the content of the source and destination locations and finding the delta that needs to be transferred.
final
excludes → List<FilterRule>?
A list of filter rules that determines which files to exclude from a task. The list should contain a single filter string that consists of the patterns to exclude. The patterns are delimited by "|" (that is, a pipe), for example: "/folder1|/folder2"
final
filesTransferred → int?
The actual number of files that was transferred over the network. This value is calculated and updated on an ongoing basis during the TRANSFERRING phase. It's updated periodically when each file is read from the source and sent over the network.
final
hashCode → int
The hash code for this object.
no setterinherited
includes → List<FilterRule>?
A list of filter rules that determines which files to include when running a task. The list should contain a single filter string that consists of the patterns to include. The patterns are delimited by "|" (that is, a pipe), for example: "/folder1|/folder2"
final
options → Options?
final
result → TaskExecutionResultDetail?
The result of the task execution.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime → DateTime?
The time that the task execution was started.
final
status → TaskExecutionStatus?
The status of the task execution.
final
taskExecutionArn → String?
The Amazon Resource Name (ARN) of the task execution that was described. TaskExecutionArn is hierarchical and includes TaskArn for the task that was executed.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited