FilterRule class

Specifies which files, folders and objects to include or exclude when transferring files from source to destination.

Constructors

FilterRule({FilterType? filterType, String? value})
FilterRule.fromJson(Map<String, dynamic> json)
factory

Properties

filterType → FilterType?
The type of filter rule to apply. AWS DataSync only supports the SIMPLE_PATTERN rule type.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String?
A single filter string that consists of the patterns to include or exclude. The patterns are delimited by "|" (that is, a pipe), for example: /folder1|/folder2
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited