ListTaskExecutionsResponse class

ListTaskExecutionsResponse

Constructors

ListTaskExecutionsResponse({String? nextToken, List<TaskExecutionListEntry>? taskExecutions})
ListTaskExecutionsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
An opaque string that indicates the position at which to begin returning the next list of executed tasks.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taskExecutions → List<TaskExecutionListEntry>?
A list of executed tasks.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited