ListTasksResponse class

ListTasksResponse

Constructors

ListTasksResponse({String? nextToken, List<TaskListEntry>? tasks})
ListTasksResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
An opaque string that indicates the position at which to begin returning the next list of tasks.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tasks → List<TaskListEntry>?
A list of all the tasks that are returned.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited