StartTaskExecutionResponse class

StartTaskExecutionResponse

Constructors

StartTaskExecutionResponse({String? taskExecutionArn})
StartTaskExecutionResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taskExecutionArn → String?
The Amazon Resource Name (ARN) of the specific task execution that was started.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited