TaskExecutionResultDetail class

Describes the detailed result of a TaskExecution operation. This result includes the time in milliseconds spent in each phase, the status of the task execution, and the errors encountered.

Constructors

TaskExecutionResultDetail({String? errorCode, String? errorDetail, int? prepareDuration, PhaseStatus? prepareStatus, int? totalDuration, int? transferDuration, PhaseStatus? transferStatus, int? verifyDuration, PhaseStatus? verifyStatus})
TaskExecutionResultDetail.fromJson(Map<String, dynamic> json)
factory

Properties

errorCode → String?
Errors that AWS DataSync encountered during execution of the task. You can use this error code to help troubleshoot issues.
final
errorDetail → String?
Detailed description of an error that was encountered during the task execution. You can use this information to help troubleshoot issues.
final
hashCode → int
The hash code for this object.
no setterinherited
prepareDuration → int?
The total time in milliseconds that AWS DataSync spent in the PREPARING phase.
final
prepareStatus → PhaseStatus?
The status of the PREPARING phase.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalDuration → int?
The total time in milliseconds that AWS DataSync took to transfer the file from the source to the destination location.
final
transferDuration → int?
The total time in milliseconds that AWS DataSync spent in the TRANSFERRING phase.
final
transferStatus → PhaseStatus?
The status of the TRANSFERRING phase.
final
verifyDuration → int?
The total time in milliseconds that AWS DataSync spent in the VERIFYING phase.
final
verifyStatus → PhaseStatus?
The status of the VERIFYING phase.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited