TaskFilter class

You can use API filters to narrow down the list of resources returned by ListTasks. For example, to retrieve all tasks on a source location, you can use ListTasks with filter name LocationId and Operator Equals with the ARN for the location.

Constructors

TaskFilter({required TaskFilterName name, required Operator operator, required List<String> values})

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → TaskFilterName
The name of the filter being used. Each API call supports a list of filters that are available for it. For example, LocationId for ListTasks.
final
operator → Operator
The operator that is used to compare filter values (for example, Equals or Contains). For more about API filtering operators, see query-resources.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values → List<String>
The values that you want to filter for. For example, you might want to display only tasks for a specific destination location.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited